# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector_v2.models.mark_notifications_as_read_internal_request import MarkNotificationsAsReadInternalRequest

class TestMarkNotificationsAsReadInternalRequest(unittest.TestCase):
    """MarkNotificationsAsReadInternalRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MarkNotificationsAsReadInternalRequest:
        """Test MarkNotificationsAsReadInternalRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MarkNotificationsAsReadInternalRequest`
        """
        model = MarkNotificationsAsReadInternalRequest()
        if include_optional:
            return MarkNotificationsAsReadInternalRequest(
                user_id = 56,
                source_type = '',
                source_ids = [
                    56
                    ]
            )
        else:
            return MarkNotificationsAsReadInternalRequest(
                user_id = 56,
                source_type = '',
                source_ids = [
                    56
                    ],
        )
        """

    def testMarkNotificationsAsReadInternalRequest(self):
        """Test MarkNotificationsAsReadInternalRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
